pub enum ClickBase {
Mil,
Moa,
Smoa,
}Expand description
Angular base unit for a turret click graduation (MBA-1355). A click graduation is always expressed in mil, (true) MOA, or SMOA/IPHY — never in whole clicks itself.
Variants